@@ -117,6 +117,8 @@ class Almoststatic():
         self.vars['meta'] = {}
         for k, v in config.items():
             self.env.globals[k] = v
+        # and add config as a dict
+        self.vars['config'] = config
 
         # global configuration
         self.vars['is_static'] = False
